#[non_exhaustive]pub struct DisassociateAgentKnowledgeBaseInput {
pub agent_id: Option<String>,
pub agent_version: Option<String>,
pub knowledge_base_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_id: Option<String>The unique identifier of the agent from which to disassociate the knowledge base.
agent_version: Option<String>The version of the agent from which to disassociate the knowledge base.
knowledge_base_id: Option<String>The unique identifier of the knowledge base to disassociate.
Implementations
Sourceimpl DisassociateAgentKnowledgeBaseInput
impl DisassociateAgentKnowledgeBaseInput
Sourcepub fn agent_id(&self) -> Option<&str>
pub fn agent_id(&self) -> Option<&str>
The unique identifier of the agent from which to disassociate the knowledge base.
Sourcepub fn agent_version(&self) -> Option<&str>
pub fn agent_version(&self) -> Option<&str>
The version of the agent from which to disassociate the knowledge base.
Sourcepub fn knowledge_base_id(&self) -> Option<&str>
pub fn knowledge_base_id(&self) -> Option<&str>
The unique identifier of the knowledge base to disassociate.
Sourceimpl DisassociateAgentKnowledgeBaseInput
impl DisassociateAgentKnowledgeBaseInput
Sourcepub fn builder() -> DisassociateAgentKnowledgeBaseInputBuilder
pub fn builder() -> DisassociateAgentKnowledgeBaseInputBuilder
Creates a new builder-style object to manufacture DisassociateAgentKnowledgeBaseInput.